conway_polynomials: Tables of Conway polynomials over finite fields
===================================================================

Description
-----------

Frank Lübeck's tables of Conway polynomials over finite fields.

Upstream contact
----------------

http://www.math.rwth-aachen.de/~Frank.Luebeck/data/ConwayPol/
